@@ -106,7 +106,6 @@ ModuleView::ModuleView( QWidget * parent )
     connect( d->mDefault, &QAbstractButton::clicked, this, &ModuleView::moduleDefaults );
     connect( d->mPageWidget, SIGNAL(currentPageChanged(KPageWidgetItem*,KPageWidgetItem*)),
              this, SLOT(activeModuleChanged(KPageWidgetItem*,KPageWidgetItem*)) );
-    connect( this, &ModuleView::moduleChanged, this, &ModuleView::updateButtons );
 
     d->mApplyAuthorize = new KAuth::ObjectDecorator(d->mApply);
     d->mApplyAuthorize->setAuthAction( KAuth::Action() );
@@ -371,8 +370,12 @@ void ModuleView::stateChanged()
     KCModuleProxy * activeModule = d->mPages.value( d->mPageWidget->currentPage() );
     KAuth::Action moduleAction;
     bool change = false;
+    bool defaulted = false;
+    KCModule::Buttons buttons = KCModule::NoAdditionalButton;
     if( activeModule ) {
+        buttons = activeModule->buttons();
         change = activeModule->changed();
+        defaulted = activeModule->defaulted();
 
         disconnect( d->mApplyAuthorize, SIGNAL(authorized(KAuth::Action)), this, SLOT(moduleSave()) );
         disconnect( d->mApply, SIGNAL(clicked()), this, SLOT(moduleSave()) );
@@ -386,8 +389,14 @@ void ModuleView::stateChanged()
 
     updatePageIconHeader( d->mPageWidget->currentPage() );
     d->mApplyAuthorize->setAuthAction( moduleAction );
-    d->mApply->setEnabled( change );
-    d->mReset->setEnabled( change );
+    d->mDefault->setEnabled(!defaulted);
+    d->mDefault->setVisible(buttons & KCModule::Default);
+    d->mApply->setEnabled(change);
+    d->mApply->setVisible(buttons & KCModule::Apply);
+    d->mReset->setEnabled(change);
+    d->mReset->setVisible(buttons & KCModule::Apply);
+    d->mHelp->setEnabled(buttons & KCModule::Help );
+    d->mHelp->setVisible(buttons & KCModule::Help );
     emit moduleChanged( change );
 }
 
@@ -410,22 +419,6 @@ void ModuleView::keyPressEvent ( QKeyEvent * event )
     QWidget::keyPressEvent( event );
 }
 
-void ModuleView::updateButtons()
-{
-    KCModuleProxy * activeModule = d->mPages.value( d->mPageWidget->currentPage() );
-    if( !activeModule ) {
-        return;
-    }
-
-    const int buttons = activeModule->buttons();
-
-    d->mApply->setVisible(buttons & KCModule::Apply );
-    d->mReset->setVisible(buttons & KCModule::Apply );
-
-    d->mHelp->setEnabled(buttons & KCModule::Help );
-    d->mDefault->setEnabled(buttons & KCModule::Default );
-}
-
 void ModuleView::setFaceType(KPageView::FaceType type)
 {
     d->mPageWidget->setFaceType(type);
