@@ -32,7 +32,7 @@ class KCModuleProxy;
 class KPageWidgetItem;
 
 /**
- * @brief Provides a convienent way to display modules
+ * @brief Provides a convenient way to display modules
  *
  * Provides a standardised interface for displaying multiple modules simultaneously
  * and provides facilities to access the current module, and to load its help, restore
@@ -137,7 +137,6 @@ private:
 
 private Q_SLOTS:
     void activeModuleChanged( KPageWidgetItem* current, KPageWidgetItem* previous);
-    void updateButtons();
     void stateChanged();
 
 Q_SIGNALS:
